@@ -18,13 +18,15 @@ Copyright Mark Harfouche 2019
 from datetime import datetime, timedelta
 from prettytable import PrettyTable, MARKDOWN
 import requests
-from distutils.version import LooseVersion
+from packaging.version import Version
 
 
 def major_minor_version(version):
-    """Given a version string, returns the major and minor version a tuple"""
-    split = version.split('.')
-    return int(split[0]), int(split[1])
+    """Given a version, returns the tuple epoch, major, minor"""
+    # version.release works in either packaging 19 or 20
+    # as of packaging 20+, can use version.major, version.minor instead
+    major, minor = version.release[:2]
+    return version.epoch, major, minor
 
 
 def keep_oldest_minor_only(version_dates):
@@ -46,11 +48,19 @@ def get_versions_dates(package_name, skip_rc=True):
     release_dates = []
     for k, v in response['releases'].items():
         # print(k)
+        # NOTE: for a version that doesn't comply to PEP 440, this will
+        # raise packaging.version.InvalidVersion:
+        version = Version(k)
         for item in v:
             # print(item['packagetype'])
             if item['packagetype'] == 'sdist':
-                if skip_rc and 'rc' in k:
-                    continue
+                if version.is_prerelease:
+                    if skip_rc or not version.pre[0] == 'rc':
+                        # skip unless we do not skip RCs and this is RC
+                        continue
+                # alt: interpret skip_rc as allow any prerelease (e.g, betas)
+                # if skip_rc and version.is_prerelease:
+                    # continue
                 upload_time = item['upload_time_iso_8601']
                 for format in ['%Y-%m-%dT%H:%M:%S.%fZ',
                                '%Y-%m-%dT%H:%M:%SZ']:
@@ -64,7 +74,7 @@ def get_versions_dates(package_name, skip_rc=True):
                         f"Could not convert {upload_time} into a standard "
                         "datetime object")
 
-                release_dates.append((k, date))
+                release_dates.append((version, date))
 
     release_dates.sort(key=lambda x: x[1], reverse=True)
     return release_dates
@@ -110,7 +120,7 @@ def nep29_versions(package_name, *,
                    skip_rc=True,
                    release_date=None,
                    consider_first_minor_only=True):
-    version_dates = get_versions_dates(package_name, skip_rc=True)
+    version_dates = get_versions_dates(package_name, skip_rc=skip_rc)
     if consider_first_minor_only:
         version_dates = keep_oldest_minor_only(version_dates)
     good_nep29_date_indicator = good_nep29_date(version_dates,
@@ -128,7 +138,7 @@ def nep29_versions(package_name, *,
                       for vd, good in zip(version_dates, good_indicator)
                       if good]
 
-    valid_releases.sort(key=lambda x: LooseVersion(x[0]), reverse=True)
+    valid_releases.sort(reverse=True)
     return valid_releases
 
 
